@@ -70,19 +70,6 @@ void CheckBox::setOpacity(qreal opacity) {
     }
 }
 
-void CheckBox::setFocus(bool focus) {
-    Q_D(const CheckBox);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 QString CheckBox::iconSource() const {
     return this->icon().name();
 }
@@ -146,6 +133,9 @@ void CheckBox::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
