@@ -34,14 +34,18 @@
 #include "grid_p.h"
 #include "headerview_p.h"
 #include "image_p.h"
+#include "imageborder_p.h"
 #include "imageproviders_p.h"
 #include "informationbox_p.h"
 #include "item_p.h"
 #include "itemaction_p.h"
 #include "keys_p.h"
 #include "label_p.h"
+//#include "listelement_p.h"
 #include "listitem_p.h"
+#include "listitemborderimage_p.h"
 #include "listitemimage_p.h"
+#include "listitemlabel_p.h"
 #include "listitemmousearea_p.h"
 #include "listitemprogressbar_p.h"
 #include "listitemrectangle_p.h"
@@ -58,6 +62,9 @@
 #include "pagestack_p.h"
 #include "platformstyle_p.h"
 #include "progressbar_p.h"
+#include "qdeclarativebind_p.h"
+#include "qdeclarativeconnections_p.h"
+#include "qdeclarativetimer_p.h"
 #include "radiobutton_p.h"
 #include "rectangle_p.h"
 #include "repeater_p.h"
@@ -66,13 +73,13 @@
 #include "separator_p.h"
 #include "slider_p.h"
 #include "spinbox_p.h"
+#include "sortfilterproxymodel_p.h"
 #include "tabbar_p.h"
 #include "tabgroup_p.h"
 #include "tableview_p.h"
 #include "text_p.h"
 #include "textedit_p.h"
 #include "textfield_p.h"
-#include "timer_p.h"
 #include "timeselector_p.h"
 #include "toolbar_p.h"
 #include "toolbutton_p.h"
@@ -80,7 +87,7 @@
 #include "valueselector_p.h"
 #include "window_p.h"
 #include "zoomarea_p.h"
-#include <QDeclarativeEngine>
+#include "private/qdeclarativecomponent_p.h"
 #include <QDeclarativeContext>
 
 void Plugin::initializeEngine(QDeclarativeEngine *engine, const char *uri) {
@@ -99,7 +106,6 @@ void Plugin::initializeEngine(QDeclarativeEngine *engine, const char *uri) {
 
         qmlRegisterUncreatableType<PlatformStyle>(uri, 1, 0, "PlatformStyle", "");
         qmlRegisterUncreatableType<Screen>(uri, 1, 0, "Screen", "");
-        qmlRegisterUncreatableType<PageStack>(uri, 1, 0, "PageStack", "");
     }
 }
 
@@ -109,16 +115,19 @@ void Plugin::registerTypes(const char *uri) {
     qRegisterMetaType<AnchorLine>("AnchorLine");
     qRegisterMetaType<KeyEvent*>("KeyEvent*");
 
+    qmlRegisterUncreatableType<Anchors>(uri, 1, 0, "Anchors", "");
+    qmlRegisterUncreatableType<Border>(uri, 1, 0, "Border", "");
+    qmlRegisterUncreatableType<ImageBorder>(uri, 1, 0, "ImageBorder", "");
+    qmlRegisterUncreatableType<Keys>(uri, 1, 0, "Keys", "");
+    qmlRegisterUncreatableType<KeyEvent>(uri, 1, 0, "KeyEvent", "");
+    qmlRegisterUncreatableType<MouseDrag>(uri, 1, 0, "Drag", "");
+    qmlRegisterUncreatableType<PageStack>(uri, 1, 0, "PageStack", "");
     qmlRegisterUncreatableType<QWidget>(uri, 1, 0, "Widget", "");
     qmlRegisterUncreatableType<QAbstractButton>(uri, 1, 0, "AbstractButton", "");
     qmlRegisterUncreatableType<QHeaderView>(uri, 1, 0, "QHeaderView", "");
-    qmlRegisterUncreatableType<Keys>(uri, 1, 0, "Keys", "");
-    qmlRegisterUncreatableType<KeyEvent>(uri, 1, 0, "KeyEvent", "");
 
     qmlRegisterType<Action>(uri, 1, 0, "Action");
     qmlRegisterType<ActionGroup>(uri, 1, 0, "ActionGroup");
-    qmlRegisterType<Anchors>(uri, 1, 0, "Anchors");
-    qmlRegisterType<Border>(uri, 1, 0, "Border");
     qmlRegisterType<BorderImage>(uri, 1, 0, "BorderImage");
     qmlRegisterType<Button>(uri, 1, 0, "Button");
     qmlRegisterType<ButtonRow>(uri, 1, 0, "ButtonRow");
@@ -136,13 +145,14 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<HeaderSection>(uri, 1, 0, "HeaderSection");
     qmlRegisterType<HeaderView>(uri, 1, 0, "HeaderView");
     qmlRegisterType<Image>(uri, 1, 0, "Image");
-    qmlRegisterType<ImageBorder>(uri, 1, 0, "ImageBorder");
     qmlRegisterType<InformationBox>(uri, 1, 0, "InformationBox");
     qmlRegisterType<Item>(uri, 1, 0, "Item");
     qmlRegisterType<ItemAction>(uri, 1, 0, "ItemAction");
     qmlRegisterType<Label>(uri, 1, 0, "Label");
     qmlRegisterType<ListItem>(uri, 1, 0, "ListItem");
+    qmlRegisterType<ListItemBorderImage>(uri, 1, 0, "ListItemBorderImage");
     qmlRegisterType<ListItemImage>(uri, 1, 0, "ListItemImage");
+    qmlRegisterType<ListItemLabel>(uri, 1, 0, "ListItemLabel");
     qmlRegisterType<ListItemMouseArea>(uri, 1, 0, "ListItemMouseArea");
     qmlRegisterType<ListItemProgressBar>(uri, 1, 0, "ListItemProgressBar");
     qmlRegisterType<ListItemRectangle>(uri, 1, 0, "ListItemRectangle");
@@ -153,11 +163,12 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Loader>(uri, 1, 0, "Loader");
     qmlRegisterType<Menu>(uri, 1, 0, "Menu");
     qmlRegisterType<MouseArea>(uri, 1, 0, "MouseArea");
-    qmlRegisterType<MouseDrag>(uri, 1, 0, "Drag");
     qmlRegisterType<MultiListSelector>(uri, 1, 0, "MultiListSelector");
     qmlRegisterType<Page>(uri, 1, 0, "Page");
     qmlRegisterType<ProgressBar>(uri, 1, 0, "ProgressBar");
-//    qmlRegisterType<QDeclarativeComponent>(uri, 1, 0, "Component");
+    qmlRegisterType<QDeclarativeBind>(uri, 1, 0, "Binding");
+    qmlRegisterType<QDeclarativeComponent>(uri, 1, 0, "Component");
+    qmlRegisterType<QDeclarativeTimer>(uri, 1, 0, "Timer");
     qmlRegisterType<QDoubleValidator>(uri, 1, 0, "DoubleValidator");
     qmlRegisterType<QIntValidator>(uri, 1, 0, "IntValidator");
     qmlRegisterType<QRegExpValidator>(uri, 1, 0, "RegExpValidator");
@@ -166,8 +177,9 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Rectangle>(uri, 1, 0, "Rectangle");
     qmlRegisterType<Repeater>(uri, 1, 0, "Repeater");
     qmlRegisterType<Row>(uri, 1, 0, "Row");
-    qmlRegisterType<Separator>(uri, 1, 0, "Separator");
+    qmlRegisterType<Separator>(uri, 1, 0, "MenuSeparator");
     qmlRegisterType<Slider>(uri, 1, 0, "Slider");
+    qmlRegisterType<SortFilterProxyModel>(uri, 1, 0, "SortFilterProxyModel");
     qmlRegisterType<SpinBox>(uri, 1, 0, "SpinBox");
     qmlRegisterType<TabBar>(uri, 1, 0, "TabBar");
     qmlRegisterType<TabButton>(uri, 1, 0, "TabButton");
@@ -176,7 +188,6 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Text>(uri, 1, 0, "Text");
     qmlRegisterType<TextEdit>(uri, 1, 0, "TextEdit");
     qmlRegisterType<TextField>(uri, 1, 0, "TextField");
-    qmlRegisterType<Timer>(uri, 1, 0, "Timer");
     qmlRegisterType<TimeSelector>(uri, 1, 0, "TimeSelector");
     qmlRegisterType<ToolBar>(uri, 1, 0, "ToolBar");
     qmlRegisterType<ToolButton>(uri, 1, 0, "ToolButton");
@@ -184,6 +195,9 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<ValueSelector>(uri, 1, 0, "ValueSelector");
     qmlRegisterType<Window>(uri, 1, 0, "Window");
     qmlRegisterType<ZoomArea>(uri, 1, 0, "ZoomArea");
+    
+    //qmlRegisterCustomType<ListElement>(uri, 1, 0, "ListElement", new ListElementParser);
+    qmlRegisterCustomType<QDeclarativeConnections>(uri, 1, 0, "Connections", new QDeclarativeConnectionsParser);
 }
 
 #include "moc_plugin_p.cpp"
