@@ -28,7 +28,7 @@ class FileSystemModel : public QSortFilterProxyModel
     Q_OBJECT
 
     Q_PROPERTY(QString rootPath READ rootPath WRITE setRootPath NOTIFY rootPathChanged)
-    Q_PROPERTY(int count READ count NOTIFY countChanged)
+    Q_PROPERTY(QString filterPath READ filterPath WRITE setFilterPath NOTIFY filterPathChanged)
     Q_PROPERTY(bool showDirs READ showDirs WRITE setShowDirs NOTIFY dirFilterChanged)
     Q_PROPERTY(bool showFiles READ showFiles WRITE setShowFiles NOTIFY dirFilterChanged)
     Q_PROPERTY(bool showHidden READ showHidden WRITE setShowHidden NOTIFY dirFilterChanged)
@@ -38,6 +38,7 @@ class FileSystemModel : public QSortFilterProxyModel
     Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly NOTIFY readOnlyChanged)
     Q_PROPERTY(bool nameFilterDisables READ nameFilterDisables WRITE setNameFilterDisables NOTIFY nameFilterDisablesChanged)
     Q_PROPERTY(QStringList nameFilters READ nameFilters WRITE setNameFilters NOTIFY nameFiltersChanged)
+    Q_PROPERTY(QStringList loadedDirectories READ loadedDirectories NOTIFY directoryLoaded)
 
     Q_ENUMS(Roles)
 
@@ -54,8 +55,9 @@ public:
 
     QString rootPath() const;
     void setRootPath(const QString &path);
-
-    int count() const;
+    
+    QString filterPath() const;
+    void setFilterPath(const QString &path);
 
     bool showDirs() const;
     void setShowDirs(bool show);
@@ -83,6 +85,12 @@ public:
 
     QStringList nameFilters() const;
     void setNameFilters(const QStringList &filters);
+    
+    QStringList loadedDirectories() const;
+    
+    Q_INVOKABLE bool directoryIsLoaded(const QString &directory) const;
+    
+    Q_INVOKABLE int count(const QModelIndex &parent = QModelIndex()) const;
 
     Q_INVOKABLE QVariant data(const QModelIndex &index, int role = FileNameRole) const;
     Q_INVOKABLE bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
@@ -103,8 +111,8 @@ public:
 
 signals:
     void rootPathChanged();
-    void directoryLoaded();
-    void countChanged();
+    void filterPathChanged();
+    void directoryLoaded(const QString &directory);
     void resolveSymlinksChanged();
     void readOnlyChanged();
     void nameFilterDisablesChanged();
@@ -113,10 +121,14 @@ signals:
 
 protected:
     FileSystemModel(FileSystemModelPrivate &dd, QObject *parent = 0);
+    
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
 
     QScopedPointer<FileSystemModelPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(FileSystemModel)
+    
+    Q_PRIVATE_SLOT(d_func(), void _q_onDirectoryLoaded(QString))
 
 private:
     Q_DISABLE_COPY(FileSystemModel)
